import stan
import arviz as az
import pickle

Stan_Model = """
data{
    int N;
    int k;
}
parameters{
    simplex[2] theta;
}
model{
    k ~ binomial(N, theta[1]);
}
"""

Data = {'N': 10, 'k': 7}
sm = stan.build(Stan_Model, data = Data)
fit = sm.sample()

with open('v_theta.pkl', 'wb') as f:
    pickle.dump(fit['theta'], f)
dframe = fit.to_frame()
print('Keys...\n', dframe.keys())
with open('dframe.pkl', 'wb') as f:
    pickle.dump(dframe, f)
inference_data = az.from_pystan(posterior = fit, posterior_model = sm)
with open('inf_data.pkl', 'wb') as f:
    pickle.dump(inference_data, f)

print(az.summary(inference_data))
